@@ -3,5 +3,5 @@ def build_headers(module):
         return {"API-KEY": module.altscore_client.api_key}
     elif isinstance(module.altscore_client.user_token, str):
         user_token = module.altscore_client.user_token.replace("Bearer ", "")
-        return {"API-KEY": f"{user_token}"}
+        return {"Authorization": f"Bearer {user_token}"}
     return {}
