@@ -26,6 +26,11 @@ from altscore.borrower_central.model.risk_ratings import RiskRatingsAsyncModule,
 from altscore.borrower_central.model.usecases import UsecasesAsyncModule, UsecasesSyncModule
 from altscore.borrower_central.model.metrics import MetricsAsyncModule, MetricsSyncModule
 from altscore.borrower_central.model.policy_policies import PolicyAsyncModule, PolicySyncModule
+from altscore.borrower_central.model.kpis import KpisAsyncModule, KpisSyncModule
+from altscore.borrower_central.model.steps import StepsAsyncModule, StepsSyncModule
+from altscore.borrower_central.model.list_of_similar import ListOfSimilarAsyncModule, ListOfSimilarSyncModule
+from altscore.borrower_central.model.execution_batches import ExecutionBatchAsyncModule, ExecutionBatchSyncModule
+from altscore.borrower_central.model.cms_settings import CMSSettingsAsyncModule, CMSSettingsSyncModule
 
 
 class BorrowerCentralAsync:
@@ -59,6 +64,11 @@ class BorrowerCentralAsync:
         self.policies = PolicyAsyncModule(altscore_client)
         self.sat_integration = SatIntegrationAsyncModule(altscore_client)
         self.usecases = UsecasesAsyncModule(altscore_client)
+        self.kpis = KpisAsyncModule(altscore_client)
+        self.steps = StepsAsyncModule(altscore_client)
+        self.list_of_similar = ListOfSimilarAsyncModule(altscore_client)
+        self.execution_batches = ExecutionBatchAsyncModule(altscore_client)
+        self.cms_settings = CMSSettingsAsyncModule(altscore_client)
 
 
 class BorrowerCentralSync:
@@ -92,3 +102,8 @@ class BorrowerCentralSync:
         self.policies = PolicySyncModule(altscore_client)
         self.sat_integration = SatIntegrationSyncModule(altscore_client)
         self.usecases = UsecasesSyncModule(altscore_client)
+        self.kpis = KpisSyncModule(altscore_client)
+        self.steps = StepsSyncModule(altscore_client)
+        self.list_of_similar = ListOfSimilarSyncModule(altscore_client)
+        self.execution_batches = ExecutionBatchSyncModule(altscore_client)
+        self.cms_settings = CMSSettingsSyncModule(altscore_client)
