@@ -42,6 +42,7 @@ class StepDataInBorrower(BaseModel):
 
 class BorrowerAPIDTO(BaseModel):
     id: str = Field(alias="id")
+    external_id: Optional[str] = Field(alias="externalId", default=None)
     persona: str = Field(alias="persona")
     avatar_url: Optional[str] = Field(alias="avatarUrl")
     label: Optional[str] = Field(alias="label")
@@ -63,7 +64,7 @@ class BorrowerAPIDTO(BaseModel):
 class SimplifiedIdentity(BaseModel):
     id: str = Field(alias="id")
     key: str = Field(alias="key")
-    label: str = Field(alias="label")
+    label: Optional[str] = Field(alias="label")
     value: Optional[str] = Field(alias="value")
     priority: Optional[int] = Field(alias="priority")
 
@@ -76,7 +77,7 @@ class SimplifiedIdentity(BaseModel):
 class SimplifiedField(BaseModel):
     id: str = Field(alias="id")
     key: str = Field(alias="key")
-    label: str = Field(alias="label")
+    label: Optional[str] = Field(alias="label")
     value: Optional[str] = Field(alias="value")
 
     class Config:
@@ -105,6 +106,7 @@ class CurrentStep(BaseModel):
 
 class BorrowerSummaryAPIDTO(BaseModel):
     id: str = Field(alias="id")
+    external_id: Optional[str] = Field(alias="externalId", default=None)
     persona: str = Field(alias="persona")
     label: Optional[str] = Field(alias="label")
     flag: Optional[str] = Field(alias="flag")
@@ -128,6 +130,7 @@ class BorrowerSummaryAPIDTO(BaseModel):
 
 class CreateBorrowerDTO(BaseModel):
     persona: str = Field(alias="persona")
+    external_id: str = Field(alias="externalId", default=None)
     label: Optional[str] = Field(alias="label")
     risk_rating: Optional[str] = Field(alias="riskRating", default=None)
     repayment_risk_rating: Optional[int] = Field(alias="repaymentRiskRating", default=None)
@@ -150,6 +153,24 @@ class UpdateBorrowerDTO(BaseModel):
         populate_by_alias = True
 
 
+class BorrowerLoginAPIDTO(BaseModel):
+    otp_id: str = Field(alias="otpId")
+
+    class Config:
+        populate_by_name = True
+        allow_population_by_field_name = True
+        allow_population_by_alias = True
+
+
+class BorrowerExportAPIDTO(BaseModel):
+    signed_url: str = Field(alias="signedUrl")
+
+    class Config:
+        populate_by_name = True
+        allow_population_by_field_name = True
+        allow_population_by_alias = True
+
+
 class BorrowerBase:
     resource = "borrowers"
 
@@ -529,6 +550,28 @@ class BorrowersAsyncModule:
         results = [item for sublist in results for item in sublist]
         return results
 
+    @retry_on_401_async
+    async def commands_borrower_login(self, borrower_id: str):
+        async with httpx.AsyncClient(base_url=self.altscore_client._borrower_central_base_url) as client:
+            response = await client.post(
+                f"/{borrower_id}/commands/login",
+                headers=self.build_headers(),
+                timeout=120
+            )
+            raise_for_status_improved(response)
+            return BorrowerLoginAPIDTO.parse_obj(response.json())
+
+    @retry_on_401_async
+    async def commands_export(self):
+        async with httpx.AsyncClient(base_url=self.altscore_client._borrower_central_base_url) as client:
+            response = await client.post(
+                "/v1/borrowers/commands/export",
+                headers=self.build_headers(),
+                timeout=120
+            )
+            raise_for_status_improved(response)
+            return BorrowerExportAPIDTO.parse_obj(response.json())
+
 
 class BorrowersSyncModule:
 
@@ -729,6 +772,28 @@ class BorrowersSyncModule:
         resources = [item for sublist in resources for item in sublist]
         return resources
 
+    @retry_on_401
+    def commands_borrower_login(self, borrower_id: str):
+        with httpx.Client(base_url=self.altscore_client._borrower_central_base_url) as client:
+            response = client.post(
+                f"/{borrower_id}/commands/login",
+                headers=self.build_headers(),
+                timeout=120
+            )
+            raise_for_status_improved(response)
+            return BorrowerLoginAPIDTO.parse_obj(response.json())
+
+    @retry_on_401
+    def commands_export(self):
+        with httpx.Client(base_url=self.altscore_client._borrower_central_base_url) as client:
+            response = client.post(
+                "/v1/borrowers/commands/export",
+                headers=self.build_headers(),
+                timeout=120
+            )
+            raise_for_status_improved(response)
+            return BorrowerExportAPIDTO.parse_obj(response.json())
+
 
 class BorrowerAsync(BorrowerBase):
     data: BorrowerAPIDTO
@@ -1211,6 +1276,19 @@ class BorrowerAsync(BorrowerBase):
             raise_for_status_improved(response)
             return None
 
+    @retry_on_401_async
+    async def set_external_id(self, external_id: str):
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.put(
+                f"{self.base_url}/v1/borrowers/{self.data.id}/external-id",
+                headers=self._header_builder(),
+                json={
+                    "externalId": external_id
+                }
+            )
+            raise_for_status_improved(response)
+            return None
+
     def __str__(self):
         return str(self.data)
 
@@ -1698,6 +1776,19 @@ class BorrowerSync(BorrowerBase):
             raise_for_status_improved(response)
             return None
 
+    @retry_on_401
+    def set_external_id(self, external_id: str):
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.put(
+                f"{self.base_url}/v1/borrowers/{self.data.id}/external-id",
+                headers=self._header_builder(),
+                json={
+                    "externalId": external_id
+                }
+            )
+            raise_for_status_improved(response)
+            return None
+
     def __str__(self):
         return str(self.data)
 
