@@ -3,6 +3,7 @@ from typing import Optional, Dict, Any, List
 from altscore.borrower_central.model.generics import GenericSyncResource, GenericAsyncResource, \
     GenericSyncModule, GenericAsyncModule, convert_to_dash_case
 from altscore.borrower_central.model.attachments import AttachmentInput, AttachmentAPIDTO
+from altscore.borrower_central.model.workflows import WorkflowExecutionResponseAPIDTO
 from altscore.common.http_errors import raise_for_status_improved, retry_on_401, retry_on_401_async
 import httpx
 import datetime as dt
@@ -24,6 +25,14 @@ class CreateExecutionDTO(BaseModel):
         allow_population_by_field_name = True
         allow_population_by_alias = True
 
+class ExecutionBatchMeta(BaseModel):
+    id: str = Field(alias="id")
+    item_index: int = Field(alias="itemIndex")
+
+    class Config:
+        populate_by_name = True
+        allow_population_by_field_name = True
+        allow_population_by_alias = True
 
 class ExecutionAPIDTO(BaseModel):
     id: Optional[str] = Field(alias="id")
@@ -33,6 +42,7 @@ class ExecutionAPIDTO(BaseModel):
     workflow_version: str = Field(alias="workflowVersion")
     workflow_type: Optional[str] = Field(alias="workflowType")
     batch_id: Optional[str] = Field(alias="batchId")
+    execution_batch: Optional[ExecutionBatchMeta] = Field(alias="executionBatch", default=None)
     billable_id: Optional[str] = Field(alias="billableId")
     borrower_id: Optional[str] = Field(alias="borrowerId")
     status: Optional[str] = Field(alias="status", default=None)
@@ -228,6 +238,20 @@ class ExecutionSync(GenericSyncResource):
             raise_for_status_improved(response)
             self.get_output()
 
+    @retry_on_401
+    def retry(self, execution_mode: Optional[str] = None):
+        headers = self._header_builder()
+        if execution_mode is not None:
+            headers["X-Execution-Mode"] = execution_mode
+        with httpx.Client() as client:
+            response = client.post(
+                f"{self.base_url}/v1/{self.resource}/{self.data.id}/retry",
+                headers=headers,
+                timeout=900
+            )
+            raise_for_status_improved(response)
+            return WorkflowExecutionResponseAPIDTO.parse_obj(response.json())
+
 
 class ExecutionAsync(GenericAsyncResource):
     output: ExecutionOutputDataAPIDTO
@@ -306,6 +330,20 @@ class ExecutionAsync(GenericAsyncResource):
             raise_for_status_improved(response)
             await self.get_output()
 
+    @retry_on_401_async
+    async def retry(self, execution_mode: Optional[str] = None):
+        headers = self._header_builder()
+        if execution_mode is not None:
+            headers["X-Execution-Mode"] = execution_mode
+        async with httpx.AsyncClient() as client:
+            response = await client.post(
+                f"{self.base_url}/v1/{self.resource}/{self.data.id}/retry",
+                headers=headers,
+                timeout=900
+            )
+            raise_for_status_improved(response)
+            return WorkflowExecutionResponseAPIDTO.parse_obj(response.json())
+
 
 class ExecutionSyncModule(GenericSyncModule):
 
