@@ -1,11 +1,14 @@
 from pydantic import BaseModel, Field
 from typing import Optional, List
 import httpx
+
+from altscore.cms.model.disbursement_accounts import CreateDisbursementClientAccountDTO, BankAccount, \
+    DisbursementClientAccountAPIDTO
 from altscore.common.http_errors import raise_for_status_improved, retry_on_401, retry_on_401_async
 from altscore.cms.model.credit_accounts import CreditAccountSync, CreditAccountAsync, CreditAccountAPIDTO
 from altscore.cms.model.payment_accounts import PaymentAccountAPIDTO, CreatePaymentAccountDTO, \
     CreatePaymentReferenceDTO, Reference
-from altscore.cms.model.generics import GenericSyncModule, GenericAsyncModule
+from altscore.cms.model.generics import GenericSyncModule, GenericAsyncModule, convert_to_dash_case
 import datetime as dt
 
 
@@ -45,6 +48,10 @@ class CreateClientDTO(BaseModel):
         allow_population_by_field_name = True
         populate_by_alias = True
 
+class UpdateClientDTO(BaseModel):
+    tax_id: Optional[str] = Field(alias="taxId", default=None)
+    legal_name: Optional[str] = Field(alias="legalName", default=None)
+    email_address: Optional[str] = Field(alias="emailAddress", default=None)
 
 class ClientBase:
 
@@ -75,6 +82,18 @@ class ClientBase:
     def _cancel_payment_reference(client_id: str, reference_id: str):
         return f"/v1/payments/accounts/{client_id}/references{reference_id}/cancellation"
 
+    @staticmethod
+    def _create_disbursement_account(country: str):
+        return f"/v1/disbursements/accounts/{country}/client"
+
+    @staticmethod
+    def _get_disbursement_accounts(country: str, client_id: str):
+        return f"/v1/disbursements/accounts/{country}/client/{client_id}"
+
+    @staticmethod
+    def _get_disbursement_account(country: str, client_id: str, account_id: str):
+        return f"/v1/disbursements/accounts/{country}/client/{client_id}/{account_id}"
+
 
 class ClientAsync(ClientBase):
     data: ClientAPIDTO
@@ -172,6 +191,57 @@ class ClientAsync(ClientBase):
             raise_for_status_improved(response)
             return [Reference.parse_obj(e) for e in response.json()]
 
+    @retry_on_401_async
+    async def create_disbursement_account(self,bank_account :dict,country: str):
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.post(
+                self._create_disbursement_account(country),
+                headers=self._header_builder(partner_id=self.data.partner_id),
+                json=CreateDisbursementClientAccountDTO.parse_obj({
+                    "id": self.data.id,
+                    "partnerId":self.data.partner_id,
+                    "email": self.data.email_address,
+                    "phone": self.data.phone_number,
+                    "bankAccount": BankAccount.parse_obj(bank_account).dict(by_alias=True,exclude_none=True),
+                }).dict(by_alias=True, exclude_none=True),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return DisbursementClientAccountAPIDTO.parse_obj(response.json())
+
+    @retry_on_401_async
+    async def get_disbursement_account(self, country: str, account_id: str) -> Optional[DisbursementClientAccountAPIDTO]:
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.get(
+                self._get_disbursement_account(country, self.data.id, account_id),
+                headers=self._header_builder(x_partner_id=self.data.partner_id),
+                timeout=30
+            )
+            if response.status_code == 404:
+                return None
+            raise_for_status_improved(response)
+            return DisbursementClientAccountAPIDTO.parse_obj(response.json())
+
+    @retry_on_401_async
+    async def get_disbursement_accounts(self, country: str, **kwargs) -> List[DisbursementClientAccountAPIDTO]:
+        query_params = {}
+        for k, v in kwargs.items():
+            if v is not None:
+                query_params[convert_to_dash_case(k)] = v
+        query_params["limit"] = 10
+        query_params["offset"] = 0
+        headers = self._header_builder()
+        headers["x-partner-id"] = self.data.partner_id
+
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.get(
+                self._get_disbursement_accounts(country, self.data.id),
+                headers=headers,
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return [DisbursementClientAccountAPIDTO.parse_obj(e) for e in response.json()]
+
     def __str__(self):
         return str(self.data)
 
@@ -274,6 +344,60 @@ class ClientSync(ClientBase):
             raise_for_status_improved(response)
             return [Reference.parse_obj(e) for e in response.json()]
 
+    @retry_on_401
+    def create_disbursement_account(self,  country: str, bank_account: dict,):
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.post(
+                self._create_disbursement_account(country),
+                headers=self._header_builder(partner_id=self.data.partner_id),
+                json=CreateDisbursementClientAccountDTO.parse_obj({
+                    "id": self.data.id,
+                    "partnerId": self.data.partner_id,
+                    "email": self.data.email_address,
+                    "phone": self.data.phone_number,
+                    "bankAccount": BankAccount.parse_obj(bank_account).dict(by_alias=True, exclude_none=True),
+                }).dict(by_alias=True, exclude_none=True),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return DisbursementClientAccountAPIDTO.parse_obj(response.json())
+
+    @retry_on_401
+    def get_disbursement_accounts(self, country: str, **kwargs) -> List[DisbursementClientAccountAPIDTO]:
+        query_params = {}
+        for k, v in kwargs.items():
+            if v is not None:
+                query_params[convert_to_dash_case(k)] = v
+        query_params["limit"] = 10
+        query_params["offset"] = 0
+        headers = self._header_builder()
+        headers["x-partner-id"] = self.data.partner_id
+
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.get(
+                self._get_disbursement_accounts(country, self.data.id),
+                headers=headers,
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return [DisbursementClientAccountAPIDTO.parse_obj(e) for e in response.json()]
+
+    @retry_on_401
+    def get_disbursement_account(self, country: str, account_id: str) -> Optional[DisbursementClientAccountAPIDTO]:
+        headers = self._header_builder()
+        headers["x-partner-id"] = self.data.partner_id
+
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.get(
+                self._get_disbursement_account(country, self.data.id, account_id),
+                headers=headers,
+                timeout=30
+            )
+            if response.status_code == 404:
+                return None
+            raise_for_status_improved(response)
+            return DisbursementClientAccountAPIDTO.parse_obj(response.json())
+
     def __str__(self):
         return str(self.data)
 
@@ -347,7 +471,7 @@ class ClientsSyncModule(GenericSyncModule):
             sync_resource=ClientSync,
             retrieve_data_model=ClientAPIDTO,
             create_data_model=CreateClientDTO,
-            update_data_model=None,
+            update_data_model=UpdateClientDTO,
             resource="clients",
             resource_version="v2"
         )
@@ -395,4 +519,4 @@ class ClientsSyncModule(GenericSyncModule):
                 timeout=30
             )
             raise_for_status_improved(response)
-            return response.json()["clientId"]
+            return response.json()["clientId"]
\ No newline at end of file
