@@ -9,12 +9,12 @@ import datetime as dt
 
 
 class Balance(BaseModel):
-    fees: Money = Field(alias="fees")
-    interest: Money = Field(alias="interest")
-    principal: Money = Field(alias="principal")
-    taxes: Money = Field(alias="taxes")
-    penalties: Money = Field(alias="penalties")
-    total: Money = Field(alias="total")
+    fees: Optional[Money] = Field(alias="fees")
+    interest: Optional[Money] = Field(alias="interest")
+    principal: Optional[Money] = Field(alias="principal")
+    taxes: Optional[Money] = Field(alias="taxes")
+    penalties: Optional[Money] = Field(alias="penalties")
+    total: Optional[Money] = Field(alias="total")
 
     class Config:
         populate_by_name = True
@@ -37,7 +37,7 @@ class Client(BaseModel):
 
 class Transaction(BaseModel):
     id: str = Field(alias="transactionId")
-    breakdown: List[Balance] = Field(alias="breakdown")
+    breakdown: Optional[List[Balance]] = Field(alias="breakdown")
     amount: Money = Field(alias="amount")
     type: str = Field(alias="type")
     date: str = Field(alias="date")
@@ -273,7 +273,7 @@ class DebtsAsyncModule(GenericAsyncModule):
             resource="debts"
         )
 
-    @retry_on_401
+    @retry_on_401_async
     async def create(self, flow_id: str, disbursement_date: Optional[str] = None, amount: Optional[dict] = None) -> str:
         if disbursement_date is not None:
             try:
